package org.vraptor.component;

import java.util.Collection;

import org.vraptor.reflection.ReflectionUtil;

/**
 * Wrapper for reflecting on Class with generic functionalities.
 * 
 * @author Guilherme Silveira
 * @since 2.3.1
 */
public class Clazz<T> {

	private final Class<T> type;

	public Clazz(Class<T> type) {
		this.type = type;
	}

	public Class<T> getType() {
		return type;
	}

	/**
	 * Creates a new instance from this type, using a default implementation of
	 * a collection when needed.
	 * 
	 * @return the new instance
	 * @throws ComponentInstantiationException
	 */
	public Object newInstance() throws ComponentInstantiationException {
		if (Collection.class.isAssignableFrom(this.type)) {
			return ReflectionUtil.instantiateCollection(this.type);
		}
		return ReflectionUtil.instantiate(this.type);
	}

}
